This directory contains code templates which are used by the
dx-app-wizard utility to create skeletons for new apps.  When
generating the code from user input, the utility will replace any of
the following strings it finds:

- DX_APP_WIZARD_NAME: the name of the app(let)
- DX_APP_WIZARD_VERSION: the version of the app(let)
- DX_APP_WIZARD_INPUT: programming language-specific signature for input to the app(let)
- DX_APP_WIZARD_OUTPUT: programming language-specific output format (if any)
